
/**
 * @file ohbbhlp.h
 * @version 0.2
 *
 * 0.2
 * Oh! Babel Helper Library interface is changed to support multiple
 * translation software. Now, ChangshinSoft ezTrans XP
 * ( http://www.cssoft.co.kr ) support is added.
 * ChangshinSoft ezTrans XP is investigated by
 * nightknight ( webmaster@mystictales.net ),
 * team leader of arcadia studio ( http://www.arcadiastudio.net ).
 * This is not compatible with Oh! Babel Helper Library 0.1
 *
 * Taeho Oh ( ohhara@postech.edu , http://ohhara.sarang.net , 2003/11/23 )
 *
 * 0.1
 * The main header file of Oh! Babel Helper Library.
 * This library is for Unisoft Babel TOP 2002. ( http://www.unisoft.co.kr )
 * Babel TOP 2002 is commercial Japanese-Korean, Korean-Japanese translation
 * software. Therefore, to use this library, you MUST buy it.
 * This library is for the programmers who are interested in using the Babel
 * TOP 2002 in their own program. Babel TOP 2002 is a translator software for
 * the normal PC users. And it's almost impossible for the programmer to use it
 * because the interface is not revealed. Now, I open the minimum interfaces of
 * Babel TOP 2002 for using the basic translator. This library may be used in
 * the various areas. For example, Babel TOP 2002 can be added to chatting
 * client and the chatting messages can be translated in a real time.
 * This source code is based on guessing without Babel TOP 2002 source code.
 * Therefore, some information may be wrong. Use this library AT YOU OWN RISK.
 * This source code can be distributed freely under BSD license.
 *
 * Taeho Oh ( ohhara@postech.edu , http://ohhara.sarang.net , 2003/11/13 )
 */

#ifndef _OHBBHLP_H_
#define _OHBBHLP_H_

#include <windows.h>

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */

#ifndef OHBEXPORT
#define OHBEXPORT __declspec(dllimport)
#endif

#define OHBCALL __stdcall

typedef enum _OHBTRANSID
{
  /**
   * Not initialized translator.
   */
  OHBID_INVALID = -1,

  /**
   * Japanese-Korean ezTrans XP ChangshinSoft ( http://www.cssoft.co.kr )
   */
  OHBID_EZTR_JK = 0,

  /**
   * Korean-Japanese ezTrans XP ChangshinSoft. ( http://www.cssoft.co.kr )
   */
  OHBID_EZTR_KJ = 1,

  /**
   * Japanese-Korean Babel TOP 2002 Unisoft. ( http://www.unisoft.co.kr )
   */
  OHBID_BABEL_JK = 2,

  /**
   * Korean-Japanese Babel TOP 2002 Unisoft. ( http://www.unisoft.co.kr )
   */
  OHBID_BABEL_KJ = 3,
} OHBTRANSID;

typedef struct _OHBSETTING
{
  /**
   * Translator ID. If the specified translator is not initialized, it will
   * have OHBID_INVALID.
   */
  OHBTRANSID iTransID;

  /**
   * Translator name in unicode.
   */
  LPCWSTR szTransName;

  /**
   * Private data pointer of the user. If the user wants to pass a translator
   * dependent arguments, use this pointer.
   */
  LPVOID pData;

  /**
   * Reserved for the future use.
   */
  char reserved[20];
} OHBSETTING;

typedef struct _OHBTRANS
{
  /**
   * Translated text in unicode.
   */
  LPCWSTR lpStr;

  /**
   * OhbTrans sets this pointer with the pSetting function argument.
   */
  const OHBSETTING *pSetting;

  /**
   * Private data pointer of Oh! Babel Helper Library. The user of Oh! Babel
   * Helper Library should not touch this.
   */
  LPVOID pData;

  /**
   * Reserved for the future use.
   */
  char reserved[20];
} OHBTRANS;

/**
 * Initializes Oh! Babel Helper Library. Before using Oh! Babel Helper Library,
 * this function must be called.
 *
 * @return 0 if success, not 0 otherwise.
 */
OHBEXPORT int OHBCALL OhbInit(OHBTRANSID iTransID);

/**
 * Destroy Oh! Babel Helper Library. It cleans up the resources of Oh! Babel
 * Helper Library.
 *
 * @param pSetting OHBSETTING pointer.
 */
OHBEXPORT void OHBCALL OhbDestroy(OHBTRANSID iTransID);

/**
 * Returns OHBSETTING array and the number of elements is written to piSettings
 * address.
 *
 * @param piSettings The pointer that the number of OHBSETTING array elements
 * will written to.
 * @return The OHBSETTING array.
 */
OHBEXPORT const OHBSETTING * OHBCALL OhbGetSettings(int *piSettings);

/**
 * Translates lpStr unicode text and returns OHBTRANS pointer. Returned
 * OHBTRANS->lpStr will have translated unicode text.
 * Returned pointer should be passed to OhbFree, otherwise memory leaks occur.
 * OHBTRANS->lpStr should be copyed before calling OhbFree.
 * pSetting can be got by calling OhbGetSettings.
 *
 * @param lpStr The unicode text to be translated.
 * @param pSetting OHBSETTING pointer.
 * @return OHBTRANS pointer.
 */
OHBEXPORT const OHBTRANS * OHBCALL OhbTrans(LPCWSTR lpStr,
  const OHBSETTING *pSetting);

/**
 * Frees OHBTRANS.
 * See OhbTrans.
 *
 * @param ohbTrans The OHBTRANS pointer to be freeed.
 * @return none.
 */
OHBEXPORT void OHBCALL OhbFree(const OHBTRANS *ohbTrans);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _OHBBHLP_H_ */
